@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -33,16 +33,16 @@ class CommandDeleteEvent : public CharmCommand
     Q_OBJECT
 
 public:
-    explicit CommandDeleteEvent( const Event&, QObject* parent = nullptr );
+    explicit CommandDeleteEvent(const Event &, QObject *parent = nullptr);
     ~CommandDeleteEvent() override;
 
     bool prepare() override;
-    bool execute( ControllerInterface* ) override;
-    bool rollback( ControllerInterface* ) override;
+    bool execute(Controller *) override;
+    bool rollback(Controller *) override;
     bool finalize() override;
 
-public slots:
-    void eventIdChanged(int,int) override;
+public Q_SLOTS:
+    void eventIdChanged(int, int) override;
 
 private:
     Event m_event;
