@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -33,11 +33,11 @@ class CommandDeleteTask : public CharmCommand
     Q_OBJECT
 
 public:
-    explicit CommandDeleteTask( const Task&, QObject* parent = nullptr );
+    explicit CommandDeleteTask(const Task &, QObject *parent = nullptr);
     ~CommandDeleteTask() override;
 
     bool prepare() override;
-    bool execute( ControllerInterface* ) override;
+    bool execute(Controller *) override;
     bool finalize() override;
 
 private:
