@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -35,11 +35,11 @@ class CommandMakeAndActivateEvent : public CharmCommand
     Q_OBJECT
 
 public:
-    explicit CommandMakeAndActivateEvent( const Task&, QObject* parent );
+    explicit CommandMakeAndActivateEvent(const Task &, QObject *parent);
     ~CommandMakeAndActivateEvent() override;
 
     bool prepare() override;
-    bool execute( ControllerInterface* ) override;
+    bool execute(Controller *) override;
     bool finalize() override;
 
 private:
