@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -23,27 +23,23 @@
 */
 
 #include "CommandMakeEvent.h"
-#include "Core/ControllerInterface.h"
+#include "Core/Controller.h"
 #include "Widgets/EventView.h"
 
 #include <QDateTime>
 
-CommandMakeEvent::CommandMakeEvent( const Task& task,
-                                    QObject* parent )
-    : CharmCommand( tr("Create Event"), parent )
-    , m_task( task )
+CommandMakeEvent::CommandMakeEvent(const Task &task, QObject *parent)
+    : CharmCommand(tr("Create Event"), parent)
+    , m_task(task)
 {
 }
 
-CommandMakeEvent::CommandMakeEvent( const Event& event,
-                                    QObject* parent )
-    : CharmCommand( tr("Create Event"), parent )
-    , m_event( event )
+CommandMakeEvent::CommandMakeEvent(const Event &event, QObject *parent)
+    : CharmCommand(tr("Create Event"), parent)
+    , m_event(event)
 {
 }
 
-
-
 CommandMakeEvent::~CommandMakeEvent()
 {
 }
@@ -53,38 +49,37 @@ bool CommandMakeEvent::prepare()
     return true;
 }
 
-bool CommandMakeEvent::execute( ControllerInterface* controller )
+bool CommandMakeEvent::execute(Controller *controller)
 {
     m_rollback = false;
 
-    if(m_event.id()) //if it already has an id, this is a redo operation
-    {
+    if (m_event.id()) { //if it already has an id, this is a redo operation
         int oid = m_event.id();
         m_event = controller->cloneEvent(m_event);
         int nid = m_event.id();
-        if(oid != nid)
+        if (oid != nid)
             emit emitSlotEventIdChanged(oid, nid);
         return m_event.isValid();
     }
 
-    Event event = controller->makeEvent( m_task );
-    if ( !event.isValid() )
-         return false;
+    Event event = controller->makeEvent(m_task);
+    if (!event.isValid())
+        return false;
 
-    QDateTime start( QDateTime::currentDateTime() );
-    event.setStartDateTime( start );
-    event.setEndDateTime( start );
+    QDateTime start(QDateTime::currentDateTime());
+    event.setStartDateTime(start);
+    event.setEndDateTime(start);
 
-    if ( m_event.startDateTime().isValid() )
-        event.setStartDateTime( m_event.startDateTime() );
-    if ( m_event.endDateTime().isValid() )
-        event.setEndDateTime( m_event.endDateTime() );
-    if ( !m_event.comment().isEmpty() )
-        event.setComment( m_event.comment() );
-    if ( m_event.taskId() != 0 )
-        event.setTaskId( m_event.taskId() );
+    if (m_event.startDateTime().isValid())
+        event.setStartDateTime(m_event.startDateTime());
+    if (m_event.endDateTime().isValid())
+        event.setEndDateTime(m_event.endDateTime());
+    if (!m_event.comment().isEmpty())
+        event.setComment(m_event.comment());
+    if (m_event.taskId() != 0)
+        event.setTaskId(m_event.taskId());
 
-    if ( controller->modifyEvent( event ) ) {
+    if (controller->modifyEvent(event)) {
         m_event = event;
         return true;
     } else {
@@ -92,7 +87,7 @@ bool CommandMakeEvent::execute( ControllerInterface* controller )
     }
 }
 
-bool CommandMakeEvent::rollback(ControllerInterface *controller )
+bool CommandMakeEvent::rollback(Controller *controller)
 {
     m_rollback = true;
     return controller->deleteEvent(m_event);
@@ -100,13 +95,13 @@ bool CommandMakeEvent::rollback(ControllerInterface *controller )
 
 bool CommandMakeEvent::finalize()
 {
-    if ( m_rollback )
+    if (m_rollback)
         return false;
-    if ( m_event.isValid() ) {
-        EventView* view = dynamic_cast<EventView*>( owner() );
-        if ( view )
-            view->makeVisibleAndCurrent( m_event );
-        emit finishedOk( m_event );
+    if (m_event.isValid()) {
+        EventView *view = dynamic_cast<EventView *>(owner());
+        if (view)
+            view->makeVisibleAndCurrent(m_event);
+        emit finishedOk(m_event);
         return true;
     } else {
         return false;
@@ -115,8 +110,6 @@ bool CommandMakeEvent::finalize()
 
 void CommandMakeEvent::eventIdChanged(int oid, int nid)
 {
-    if(m_event.id() == oid)
+    if (m_event.id() == oid)
         m_event.setId(nid);
 }
-
-#include "moc_CommandMakeEvent.cpp"
