@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -31,15 +31,15 @@
 #include <QIcon>
 #include <QPixmap>
 
-const QIcon& Data::charmIcon()
+const QIcon &Data::charmIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/charmicon.png").isNull(), Q_FUNC_INFO,
-            "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/charmicon.png"));
+    static QIcon icon(QStringLiteral(":/Charm/charmicon.png"));
+    Q_ASSERT_X(!icon.isNull(), Q_FUNC_INFO,
+               "Required resource not available");
     return icon;
 }
 
-const QIcon& Data::charmTrayIcon()
+const QIcon &Data::charmTrayIcon()
 {
     // Mac and Windows: the system tray uses 16x16.
     // TODO: different icons though: white background on Windows
@@ -47,18 +47,18 @@ const QIcon& Data::charmTrayIcon()
     // KDE apps seem to get 24x24 in KSystemTrayIcon via KIconLoader, which is actually better.
 
 #ifdef Q_OS_OSX
-    static const QString iconPath = QLatin1String(":/Charm/charmtray_mac.png");
+    static const QString iconPath = QStringLiteral(":/Charm/charmtray_mac.png");
 #else
-    static const QString iconPath = QLatin1String(":/Charm/charmtray22.png");
+    static const QString iconPath = QStringLiteral(":/Charm/charmtray22.png");
 #endif
 
     Q_ASSERT_X(!QPixmap(iconPath).isNull(), Q_FUNC_INFO,
-                        "Required resource not available");
+               "Required resource not available");
     static QIcon icon = QPixmap(iconPath);
     return icon;
 }
 
-const QIcon& Data::charmTrayActiveIcon()
+const QIcon &Data::charmTrayActiveIcon()
 {
     // Mac and Windows: the system tray uses 16x16.
     // TODO: different icons though: white background on Windows
@@ -66,123 +66,124 @@ const QIcon& Data::charmTrayActiveIcon()
     // KDE apps seem to get 24x24 in KSystemTrayIcon via KIconLoader, which is actually better.
 
 #ifdef Q_OS_OSX
-    static const QString iconPath = QLatin1String(":/Charm/charmtrayactive_mac.png");
+    static const QString iconPath = QStringLiteral(":/Charm/charmtrayactive_mac.png");
 #else
-    static const QString iconPath = QLatin1String(":/Charm/charmtrayactive22.png");
+    static const QString iconPath = QStringLiteral(":/Charm/charmtrayactive22.png");
 #endif
 
     Q_ASSERT_X(!QPixmap(iconPath).isNull(), Q_FUNC_INFO,
-                        "Required resource not available");
+               "Required resource not available");
     static QIcon icon = QPixmap(iconPath);
     return icon;
 }
-const QIcon& Data::goIcon()
-{
-    Q_ASSERT_X(!QPixmap(":/Charm/go.png").isNull(), Q_FUNC_INFO,
-              "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/go.png"));
-    return icon;
-}
 
-const QIcon& Data::stopIcon()
+const QIcon &Data::goIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/stop.png").isNull(), Q_FUNC_INFO,
-            "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/stop.png"));
-    return icon;
-}
-
-const QIcon& Data::newTaskIcon()
-{
-    Q_ASSERT_X(!QPixmap(":/Charm/newtask.png").isNull(), Q_FUNC_INFO,
+    static QIcon icon(QStringLiteral(":/Charm/go.png"));
+    Q_ASSERT_X(!icon.isNull(), Q_FUNC_INFO,
                "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/newtask.png"));
     return icon;
 }
 
-const QIcon& Data::newSubtaskIcon()
+const QIcon &Data::stopIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/newsubtask.png").isNull(), Q_FUNC_INFO,
+    static QIcon icon(QStringLiteral(":/Charm/stop.png"));
+    Q_ASSERT_X(!icon.isNull(), Q_FUNC_INFO,
                "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/newsubtask.png"));
     return icon;
 }
 
-const QIcon& Data::editTaskIcon()
+const QIcon &Data::newTaskIcon()
+{
+    static QIcon icon(QStringLiteral(":/Charm/newtask.png"));
+    Q_ASSERT_X(!icon.isNull(), Q_FUNC_INFO,
+               "Required resource not available");
+    return icon;
+}
+
+const QIcon &Data::newSubtaskIcon()
+{
+    static QIcon icon(QStringLiteral(":/Charm/newsubtask.png"));
+    Q_ASSERT_X(!icon.isNull(), Q_FUNC_INFO,
+               "Required resource not available");
+    return icon;
+}
+
+const QIcon &Data::editTaskIcon()
 {   // FIXME same as edit-event icon
-    Q_ASSERT_X(!QPixmap(":/Charm/edit.png").isNull(), Q_FUNC_INFO,
+    static QIcon icon(QStringLiteral(":/Charm/edit.png"));
+    Q_ASSERT_X(!icon.isNull(), Q_FUNC_INFO,
                "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/edit.png"));
     return icon;
 }
 
-const QIcon& Data::deleteTaskIcon()
+const QIcon &Data::deleteTaskIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/deletetask.png").isNull(),
+    static QIcon icon(QStringLiteral(":/Charm/deletetask.png"));
+    Q_ASSERT_X(!icon.isNull(),
                Q_FUNC_INFO, "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/deletetask.png"));
     return icon;
 }
 
-const QIcon& Data::searchIcon()
+const QIcon &Data::searchIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/search.png").isNull(),
+    static QIcon icon(QStringLiteral(":/Charm/search.png"));
+    Q_ASSERT_X(!icon.isNull(),
                Q_FUNC_INFO, "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/search.png"));
     return icon;
 }
 
-const QIcon& Data::editEventIcon()
+const QIcon &Data::editEventIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/edit.png").isNull(), Q_FUNC_INFO,
+    static QIcon icon(QStringLiteral(":/Charm/edit.png"));
+    Q_ASSERT_X(!icon.isNull(), Q_FUNC_INFO,
                "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/edit.png"));
     return icon;
 }
 
-const QIcon& Data::createReportIcon()
+const QIcon &Data::createReportIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/createreport.png").isNull(), Q_FUNC_INFO,
+    static QIcon icon(QStringLiteral(":/Charm/createreport.png"));
+    Q_ASSERT_X(!icon.isNull(), Q_FUNC_INFO,
                "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/createreport.png"));
     return icon;
 }
 
-const QPixmap& Data::activePixmap()
+const QPixmap &Data::activePixmap()
 {
-    static QPixmap pixmap(":/Charm/active.png");
+    static QPixmap pixmap(QStringLiteral(":/Charm/active.png"));
     Q_ASSERT_X(!pixmap.isNull(), Q_FUNC_INFO,
                "Required resource not available");
     return pixmap;
 }
 
-const QIcon& Data::quitCharmIcon()
+const QIcon &Data::quitCharmIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/quitcharm.png").isNull(),
+    static QIcon icon(QStringLiteral(":/Charm/quitcharm.png"));
+    Q_ASSERT_X(!icon.isNull(),
                Q_FUNC_INFO, "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/quitcharm.png"));
     return icon;
 }
 
-const QIcon& Data::configureIcon()
+const QIcon &Data::configureIcon()
 {
-    Q_ASSERT_X(!QPixmap(":/Charm/configure.png").isNull(),
+    static QIcon icon(QStringLiteral(":/Charm/configure.png"));
+    Q_ASSERT_X(!icon.isNull(),
                Q_FUNC_INFO, "Required resource not available");
-    static QIcon icon(QPixmap(":/Charm/configure.png"));
     return icon;
 }
 
-const QPixmap& Data::editorLockedPixmap()
+const QPixmap &Data::editorLockedPixmap()
 {
-    static QPixmap pixmap(":/Charm/editor_locked.png");
+    static QPixmap pixmap(QStringLiteral(":/Charm/editor_locked.png"));
     Q_ASSERT_X(!pixmap.isNull(), Q_FUNC_INFO,
                "Required resource not available");
     return pixmap;
 }
 
-const QPixmap& Data::editorDirtyPixmap()
+const QPixmap &Data::editorDirtyPixmap()
 {
-    static QPixmap pixmap(":/Charm/editor_dirty.png");
+    static QPixmap pixmap(QStringLiteral(":/Charm/editor_dirty.png"));
     Q_ASSERT_X(!pixmap.isNull(), Q_FUNC_INFO,
                "Required resource not available");
     return pixmap;
