@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -35,40 +35,39 @@
 
 class CharmDataModel;
 
-class EventModelFilter : public QSortFilterProxyModel,
-                         public CommandEmitterInterface,
-                         public EventModelInterface
+class EventModelFilter : public QSortFilterProxyModel, public CommandEmitterInterface,
+    public EventModelInterface
 {
     Q_OBJECT
 
 public:
-    explicit EventModelFilter( CharmDataModel*, QObject* parent = nullptr );
+    explicit EventModelFilter(CharmDataModel *, QObject *parent = nullptr);
     ~EventModelFilter() override;
 
     /** Returns the total number of seconds of all events in the model. */
     int totalDuration() const;
 
     // implement EventModelInterface:
-    const Event& eventForIndex( const QModelIndex& ) const override;
-    QModelIndex indexForEvent( const Event& ) const override;
+    const Event &eventForIndex(const QModelIndex &) const override;
+    QModelIndex indexForEvent(const Event &) const override;
 
-    bool filterAcceptsRow( int srow, const QModelIndex & sparent ) const override;
+    bool filterAcceptsRow(int srow, const QModelIndex &sparent) const override;
 
-    void setFilterStartDate( const QDate& date );
-    void setFilterEndDate( const QDate& date );
-    void setFilterTaskId( TaskId id );
+    void setFilterStartDate(const QDate &date);
+    void setFilterEndDate(const QDate &date);
+    void setFilterTaskId(TaskId id);
 
     // implement CommandEmitterInterface:
-    void commitCommand( CharmCommand* ) override;
+    void commitCommand(CharmCommand *) override;
 
     // implement to sort by event start datetime
-    bool lessThan( const QModelIndex& left, const QModelIndex& right ) const override;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
     QList<Event> events() const;
 
-signals:
-    void eventActivationNotice( EventId id );
-    void eventDeactivationNotice( EventId id );
+Q_SIGNALS:
+    void eventActivationNotice(EventId id);
+    void eventDeactivationNotice(EventId id);
 
 private:
     EventModelAdapter m_model;
