@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -28,12 +28,9 @@
 #include <QNetworkRequest>
 #include <QSettings>
 
-GetProjectCodesJob::GetProjectCodesJob(QObject* parent)
+GetProjectCodesJob::GetProjectCodesJob(QObject *parent)
     : HttpJob(parent)
 {
-    QSettings s;
-    s.beginGroup(QLatin1String("httpconfig"));
-    setDownloadUrl(s.value(QLatin1String("projectCodeDownloadUrl")).toUrl());
 }
 
 GetProjectCodesJob::~GetProjectCodesJob()
@@ -45,33 +42,29 @@ QByteArray GetProjectCodesJob::payload() const
     return m_payload;
 }
 
-bool GetProjectCodesJob::execute(int state, QNetworkAccessManager *manager)
+void GetProjectCodesJob::executeRequest(QNetworkAccessManager *manager)
 {
-    if (state != GetProjectCodes)
-        return HttpJob::execute(state, manager);
     QNetworkRequest request(m_downloadUrl);
 
     QNetworkReply *reply = manager->get(request);
+    connect(reply, &QNetworkReply::finished, this, &GetProjectCodesJob::handleResult);
 
     if (reply->error() != QNetworkReply::NoError)
-        setErrorFromReplyAndEmitFinished(reply);
-    return true;
+        setErrorFromReplyAndEmitFinishedOrRestart(reply);
 }
 
-bool GetProjectCodesJob::handle(QNetworkReply *reply)
+void GetProjectCodesJob::handleResult()
 {
+    auto reply = qobject_cast<QNetworkReply*>(sender());
+    reply->deleteLater();
     /* check for failure */
     if (reply->error() != QNetworkReply::NoError) {
-        setErrorFromReplyAndEmitFinished(reply);
-        return false;
+        setErrorFromReplyAndEmitFinishedOrRestart(reply);
+        return;
     }
 
-    if (state() != GetProjectCodes)
-        return HttpJob::handle(reply);
-
     m_payload = reply->readAll();
-    delayedNext();
-    return true;
+    emitFinishedOrRestart();
 }
 
 QUrl GetProjectCodesJob::downloadUrl() const
@@ -79,12 +72,12 @@ QUrl GetProjectCodesJob::downloadUrl() const
     return m_downloadUrl;
 }
 
-void GetProjectCodesJob::setDownloadUrl(const QUrl& url)
+void GetProjectCodesJob::setDownloadUrl(const QUrl &url)
 {
     m_downloadUrl = url;
 }
 
-void GetProjectCodesJob::setVerbose( bool verbose )
+void GetProjectCodesJob::setVerbose(bool verbose)
 {
     m_verbose = verbose;
 }
@@ -93,5 +86,3 @@ bool GetProjectCodesJob::isVerbose() const
 {
     return m_verbose;
 }
-
-#include "moc_GetProjectCodesJob.cpp"
