@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -33,26 +33,21 @@ class GetProjectCodesJob : public HttpJob
     Q_OBJECT
 public:
 
-    explicit GetProjectCodesJob(QObject* parent=nullptr);
+    explicit GetProjectCodesJob(QObject *parent = nullptr);
     ~GetProjectCodesJob() override;
 
     QByteArray payload() const;
 
     QUrl downloadUrl() const;
-    void setDownloadUrl(const QUrl& url);
+    void setDownloadUrl(const QUrl &url);
     void setVerbose(bool verbose);
     bool isVerbose() const;
 
-public slots:
-
-    bool execute(int state, QNetworkAccessManager *manager) override;
-     bool handle(QNetworkReply *reply) override;
-
 protected:
+    void executeRequest(QNetworkAccessManager *) override;
 
-    enum State {
-        GetProjectCodes = HttpJob::Base
-    };
+private:
+    void handleResult();
 
 private:
     QByteArray m_payload;
