@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -28,7 +28,7 @@
 #include <QUrl>
 
 namespace QKeychain {
-    class Job;
+class Job;
 }
 
 class QNetworkAccessManager;
@@ -40,12 +40,8 @@ class HttpJob : public QObject
 {
     Q_OBJECT
 public:
-
-    static bool credentialsAvailable();
-    static bool lastAuthenticationFailed();
-
     enum Error {
-        NoError=0,
+        NoError = 0,
         Canceled,
         NotConfigured,
         AuthenticationFailed,
@@ -53,7 +49,12 @@ public:
         HostNotFound
     };
 
-    explicit HttpJob(QObject* parent=nullptr);
+    enum PasswordRequestReason {
+        NoPasswordFound,
+        PasswordIncorrect
+    };
+
+    explicit HttpJob(QObject *parent = nullptr);
     ~HttpJob() override;
 
     QString username() const;
@@ -62,12 +63,6 @@ public:
     QString password() const;
     void setPassword(const QString &value);
 
-    QUrl portalUrl() const;
-    void setPortalUrl(const QUrl &value);
-
-    QUrl loginUrl() const;
-    void setLoginUrl(const QUrl &value);
-
     QString errorString() const;
     int error() const;
 
@@ -77,7 +72,7 @@ public:
     void passwordRequestCanceled();
 
 Q_SIGNALS:
-    void finished(HttpJob*);
+    void finished(HttpJob *);
     /**
      * the actual communication was started
      */
@@ -88,50 +83,30 @@ Q_SIGNALS:
      *
      * Must be replied to via provideRequestedPassword() or passwordRequestCanceled() to continue.
      */
-    void passwordRequested();
-
-protected:
-
-    enum State {
-        Ready = 0,
-        Init,
-        Login,
-        Portal,
-        Base
-    };
-
-    int state() const;
-
-    virtual bool execute(int state, QNetworkAccessManager *manager);
-
-    void emitFinished();
-    void setErrorAndEmitFinished(int code, const QString& errorString);
-    void delayedNext();
-    void setErrorFromReplyAndEmitFinished(QNetworkReply *reply);
-
-    static QString extractErrorMessageFromReply(const QByteArray& xml);
+    void passwordRequested(PasswordRequestReason);
 
 protected Q_SLOTS:
-    virtual bool handle(QNetworkReply *reply);
+    virtual void executeRequest(QNetworkAccessManager *) = 0;
+
+protected:
+    void emitFinishedOrRestart();
+    void setErrorAndEmitFinishedOrRestart(int code, const QString &errorString);
+    void setErrorFromReplyAndEmitFinishedOrRestart(QNetworkReply *reply);
 
 private Q_SLOTS:
     void doStart();
     void doCancel();
-    void next();
-    void passwordRead(QKeychain::Job*);
+    void passwordRead(QKeychain::Job *);
     void passwordWritten();
-    void authenticationRequired(QNetworkReply *reply , QAuthenticator *authenticator);
+    void authenticationRequired(QNetworkReply *reply, QAuthenticator *authenticator);
 
 private:
     QNetworkAccessManager *m_networkManager;
     QString m_username;
     QString m_password;
-    int m_currentState = Ready;
     int m_errorCode = NoError;
     QString m_errorString;
-    QUrl m_loginUrl;
-    QUrl m_portalUrl;
-    bool m_lastAuthenticationFailed = true;
+    bool m_lastAuthenticationFailed = false;
     bool m_authenticationDoneAlready = false;
     bool m_passwordReadError = false;
 };
