@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
   Author: Guillermo A. Amaral <gamaral@kdab.com>
@@ -27,15 +27,15 @@
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QNetworkRequest>
-#include <QRegExp> // Required for Qt 4
-#include <QSettings>
 
-UploadTimesheetJob::UploadTimesheetJob(QObject* parent)
-    : HttpJob(parent), m_fileName("payload")
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QUrlQuery>
+
+UploadTimesheetJob::UploadTimesheetJob(QObject *parent)
+    : HttpJob(parent)
+    , m_fileName(QStringLiteral("payload"))
 {
-    QSettings s;
-    s.beginGroup(QLatin1String("httpconfig"));
-    setUploadUrl(s.value(QLatin1String("timesheetUploadUrl")).toUrl());
 }
 
 UploadTimesheetJob::~UploadTimesheetJob()
@@ -67,26 +67,34 @@ QUrl UploadTimesheetJob::uploadUrl() const
     return m_uploadUrl;
 }
 
-void UploadTimesheetJob::setUploadUrl(const QUrl& url)
+void UploadTimesheetJob::setUploadUrl(const QUrl &url)
 {
     m_uploadUrl = url;
 }
 
-bool UploadTimesheetJob::execute(int state, QNetworkAccessManager *manager)
+UploadTimesheetJob::Status UploadTimesheetJob::status() const
 {
-    if (state != UploadTimesheet)
-        return HttpJob::execute(state, manager);
+    return m_status;
+}
 
-    QByteArray data;
+void UploadTimesheetJob::setStatus(Status status)
+{
+    m_status = status;
+}
+
+void UploadTimesheetJob::executeRequest(QNetworkAccessManager *manager)
+{
     QByteArray uploadName;
 
     /* validate filename */
-    if (!m_fileName.contains(QRegExp("^WeeklyTimeSheet-\\d\\d\\d\\d-\\d\\d$"))) {
+    if (!m_fileName.contains(QRegExp(QStringLiteral("^WeeklyTimeSheet-\\d\\d\\d\\d-\\d\\d$")))) {
         qDebug("Invalid filename encountered, using default (\"payload\").");
         uploadName = "payload";
+    } else {
+        uploadName = m_fileName.toUtf8();
     }
-    else uploadName = m_fileName.toUtf8();
 
+    QByteArray data;
     /* username */
     data += "--KDAB\r\n"
             "Content-Disposition: form-data; name=\"user\"\r\n\r\n";
@@ -95,47 +103,47 @@ bool UploadTimesheetJob::execute(int state, QNetworkAccessManager *manager)
 
     /* payload */
     data += "--KDAB\r\n"
-            "Content-Disposition: form-data; name=\"" + uploadName + "\"; filename=\"" +
-            uploadName + "\"\r\nContent-Type: application/octet-stream\r\n\r\n";
+            "Content-Disposition: form-data; name=\"" + uploadName + "\"; filename=\""
+            +uploadName + "\"\r\nContent-Type: application/octet-stream\r\n\r\n";
     data += m_payload;
     data += "\r\n";
 
-    /* eot */
+    if (m_status == Staged) {
+        data += "--KDAB\r\n";
+        data += "Content-Disposition: form-data; name=\"status\"\r\n\r\n";
+        data += "STAGED\r\n";
+    }
+
     data += "--KDAB--\r\n";
 
     QNetworkRequest request(m_uploadUrl);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, "multipart/form-data; boundary=KDAB");
+    request.setHeader(QNetworkRequest::ContentTypeHeader,
+                      QStringLiteral("multipart/form-data; boundary=KDAB"));
     request.setHeader(QNetworkRequest::ContentLengthHeader, data.size());
 
     QNetworkReply *reply = manager->post(request, data);
-
-    if (reply->error() != QNetworkReply::NoError)
-        setErrorFromReplyAndEmitFinished(reply);
-    return true;
+    connect(reply, &QNetworkReply::finished, this, &UploadTimesheetJob::handleResult);
 }
 
-bool UploadTimesheetJob::handle(QNetworkReply *reply)
+void UploadTimesheetJob::handleResult()
 {
-    /* check for failure */
+    auto reply = qobject_cast<QNetworkReply*>(sender());
+    reply->deleteLater();
+
+    if (reply->error() == QNetworkReply::ProtocolInvalidOperationError) {
+        const auto doc = QJsonDocument::fromJson(reply->readAll());
+        const auto errorMessage = doc.object().value(QLatin1String("message")).toString();
+
+        setErrorAndEmitFinishedOrRestart(SomethingWentWrong, !errorMessage.isEmpty()
+                                         ? errorMessage
+                                         : tr("An error occurred, could not extract details"));
+        return;
+    }
+
     if (reply->error() != QNetworkReply::NoError) {
-        setErrorFromReplyAndEmitFinished(reply);
-        return false;
+        setErrorFromReplyAndEmitFinishedOrRestart(reply);
+        return;
     }
 
-    if (state() != UploadTimesheet)
-        return HttpJob::handle(reply);
-
-    const QByteArray answer = reply->readAll();
-
-    if (answer.contains("SuccessResultMessage")) {
-        delayedNext();
-    } else {
-        const QString errorMessage = extractErrorMessageFromReply(answer);
-        setErrorAndEmitFinished(SomethingWentWrong, !errorMessage.isEmpty()
-                                ? errorMessage
-                                : tr("An error occurred, could not extract details"));
-    }
-    return true;
+    emitFinishedOrRestart();
 }
-
-#include "moc_UploadTimesheetJob.cpp"
