@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -32,8 +32,12 @@ class UploadTimesheetJob : public HttpJob
 {
     Q_OBJECT
 public:
+    enum Status {
+        Unreviewed,
+        Staged
+    };
 
-    explicit UploadTimesheetJob(QObject* parent=nullptr);
+    explicit UploadTimesheetJob(QObject *parent = nullptr);
     ~UploadTimesheetJob() override;
 
     QByteArray payload() const;
@@ -41,20 +45,18 @@ public:
     QString fileName() const;
     void setFileName(const QString &fileName);
     QUrl uploadUrl() const;
-    void setUploadUrl(const QUrl& url);
+    void setUploadUrl(const QUrl &url);
 
-public slots:
+    Status status() const;
+    void setStatus(Status status);
 
-    bool execute(int state, QNetworkAccessManager *manager) override;
-    bool handle(QNetworkReply *reply) override;
+public Q_SLOTS:
 
-protected:
-
-    enum State {
-        UploadTimesheet = HttpJob::Base
-    };
+    void executeRequest(QNetworkAccessManager *manager) override;
+    void handleResult();
 
 private:
+    Status m_status = Unreviewed;
     QByteArray m_payload;
     QString m_fileName;
     QUrl m_uploadUrl;
