@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -121,8 +121,8 @@ void MacApplicationCore::Private::setupCocoaEventHandler() const
      andEventID:kAEReopenApplication];
 }
 
-MacApplicationCore::MacApplicationCore( TaskId startupTask, QObject* parent )
-    : ApplicationCore( startupTask, parent )
+MacApplicationCore::MacApplicationCore( TaskId startupTask, bool hideAtStart, QObject* parent )
+    : ApplicationCore( startupTask, hideAtStart, parent )
     , m_private( new MacApplicationCore::Private() )
 {
     m_private->dockIconClickEventHandler->macApplication = this;
