@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: David Faure <david.faure@kdab.com>
@@ -30,8 +30,7 @@
 #include "Core/CharmDataModel.h"
 #include "EventModelFilter.h"
 
-class ModelConnector : public QObject,
-                       public CommandEmitterInterface
+class ModelConnector : public QObject, public CommandEmitterInterface
 {
     Q_OBJECT
 
@@ -39,21 +38,21 @@ public:
     ModelConnector();
 
     /** The charm data model. */
-    CharmDataModel* charmDataModel();
+    CharmDataModel *charmDataModel();
     /** The item model the task view uses. */
-    ViewFilter* taskModel();
+    ViewFilter *taskModel();
     /** The item model the event view uses. */
-    EventModelFilter* eventModel();
+    EventModelFilter *eventModel();
 
-    EventModelFilter* findEventModel();
+    EventModelFilter *findEventModel();
 
     // implement CommandEmitterInterface
-    void commitCommand( CharmCommand* ) override;
+    void commitCommand(CharmCommand *) override;
 
-public slots:
-    void slotMakeAndActivateEvent( const Task& );
-    void slotRequestEventModification(const Event&newEvent, const Event& oldEvent);
-    void slotSysTrayUpdate(const QString& toolTip, bool active);
+public Q_SLOTS:
+    void slotMakeAndActivateEvent(const Task &);
+    void slotRequestEventModification(const Event &newEvent, const Event &oldEvent);
+    void slotSysTrayUpdate(const QString &toolTip, bool active);
 
 private:
     CharmDataModel m_dataModel;
