@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -24,31 +24,23 @@
 #ifndef WEEKLYTIMESHEETXMLWRITER_H
 #define WEEKLYTIMESHEETXMLWRITER_H
 
-#include "Core/Event.h"
-#include "Core/Task.h"
+#include "TimesheetXmlWriter.h"
 
-class QByteArray;
-class CharmDataModel;
-
-class WeeklyTimesheetXmlWriter {
+class WeeklyTimesheetXmlWriter : public TimesheetXmlWriter
+{
 public:
     WeeklyTimesheetXmlWriter();
-    /**
-     * @throws XmlSerializationException
-     */
-    QByteArray saveToXml() const;
 
-    void setDataModel( const CharmDataModel* model);
-    void setYear( int year );
-    void setWeekNumber( int weekNumber );
-    void setEvents( const EventList& events );
-    void setRootTask( TaskId rootTask );
+    void setYear(int year);
+    void setWeekNumber(int weekNumber);
+
+protected:
+    void writeMetadata(QDomDocument &document, QDomElement &metadata) const override;
+    QList<TimeSheetInfo> createTimeSheetInfo() const override;
+
 private:
-    const CharmDataModel* m_dataModel;
-    int m_year;
-    int m_weekNumber;
-    TaskId m_rootTask;
-    EventList m_events;
+    int m_year = 0;
+    int m_weekNumber = 0;
 };
 
 #endif
