@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -35,7 +35,8 @@ class CharmDataModel;
 class WeeklySummary
 {
 public:
-    static QVector<WeeklySummary> summariesForTimespan( CharmDataModel* dataModel, const TimeSpan& timespan );
+    static QVector<WeeklySummary> summariesForTimespan(CharmDataModel *dataModel,
+                                                       const TimeSpan &timespan);
 
     WeeklySummary();
 
