@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -29,44 +29,61 @@
 
 #include "ReportConfigurationDialog.h"
 #include "ReportPreviewWindow.h"
+#include "ViewHelpers.h"
 
 #include <QScopedPointer>
 
 namespace Ui {
-    class ActivityReportConfigurationDialog;
+class ActivityReportConfigurationDialog;
 }
 
 class QUrl;
+class QListWidgetItem;
+class QListWidget;
 
 class ActivityReportConfigurationDialog : public ReportConfigurationDialog
 {
     Q_OBJECT
 
 public:
-    explicit ActivityReportConfigurationDialog( QWidget* parent );
+    struct Properties {
+        NamedTimeSpan timeSpanSelection;
+        QDate start;
+        QDate end;
+        QSet<TaskId> rootTasks;
+        QSet<TaskId> rootExcludeTasks;
+        bool showFullDescription = false;
+        bool groupByTaskId = false;
+        bool groupByTaskIdAndComments = false;
+    };
+
+    explicit ActivityReportConfigurationDialog(QWidget *parent);
     ~ActivityReportConfigurationDialog() override;
 
     void showReportPreviewDialog() override;
 
 public Q_SLOTS:
     void accept() override;
+    void reject() override;
 
-private slots:
+private Q_SLOTS:
     void slotDelayedInitialization();
     void slotStandardTimeSpansChanged();
-    void slotTimeSpanSelected( int );
+    void slotTimeSpanSelected(int);
     void slotSelectTask();
     void slotExcludeTask();
     void slotRemoveExcludedTask();
     void slotRemoveIncludeTask();
+    void slotGroupTasks(bool checked);
+    void slotGroupTasksComments(bool checked);
 
 private:
-    bool selectTask(TaskId& task);
+    bool selectTask(TaskId &task);
+    QListWidgetItem *addListItem(TaskId id, QListWidget *list) const;
 
     QScopedPointer<Ui::ActivityReportConfigurationDialog> m_ui;
     QList<NamedTimeSpan> m_timespans;
-    QSet<TaskId> m_rootTasks;
-    QSet<TaskId> m_rootExcludeTasks;
+    ActivityReportConfigurationDialog::Properties m_properties;
 };
 
 class ActivityReport : public ReportPreviewWindow
@@ -74,25 +91,19 @@ class ActivityReport : public ReportPreviewWindow
     Q_OBJECT
 
 public:
-    explicit ActivityReport( QWidget* parent = nullptr );
+    explicit ActivityReport(QWidget *parent = nullptr);
     ~ActivityReport() override;
 
-    void setReportProperties(const QDate& start, const QDate& end,
-        QSet<TaskId> rootTasks, QSet<TaskId> rootExcludeTasks );
-    void timeSpanSelection( NamedTimeSpan timeSpanSelection );
+    void setReportProperties(const ActivityReportConfigurationDialog::Properties &properties);
 
-private slots:
-    void slotLinkClicked( const QUrl& which );
+private Q_SLOTS:
+    void slotLinkClicked(const QUrl &which);
 
 private:
     void slotUpdate() override;
 
 private:
-    QDate m_start;
-    QDate m_end;
-    QSet<TaskId> m_rootTasks;
-    QSet<TaskId> m_rootExcludeTasks;
-    NamedTimeSpan m_timeSpanSelection;
+    ActivityReportConfigurationDialog::Properties m_properties;
 };
 
 #endif
