@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -36,11 +36,11 @@ public:
         AsYouWish,
         AlreadyDone,
     };
-    explicit BillDialog(QWidget* parent = nullptr, Qt::WindowFlags f = 0);
+    explicit BillDialog(QWidget *parent = nullptr, Qt::WindowFlags f = 0);
     void setReport(int year, int week);
     int year() const;
     int week() const;
-private slots:
+private Q_SLOTS:
     void slotAsYouWish();
     void slotAlreadyDone();
     void slotLater();
