@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -34,8 +34,7 @@ class CharmPreferences : public QDialog
     Q_OBJECT
 
 public:
-    explicit CharmPreferences( const Configuration& config,
-                               QWidget* parent = nullptr );
+    explicit CharmPreferences(const Configuration &config, QWidget *parent = nullptr);
     ~CharmPreferences() override;
 
     Configuration::DurationFormat durationFormat() const;
@@ -43,13 +42,13 @@ public:
     bool warnUnuploadedTimesheets() const;
     bool requestEventComment() const;
     bool enableCommandInterface() const;
+    int numberOfTaskSelectorEntries() const;
 
     Qt::ToolButtonStyle toolButtonStyle() const;
 
     Configuration::TimeTrackerFontSize timeTrackerFontSize() const;
-private slots:
+private Q_SLOTS:
     void slotWarnUnuploadedChanged(bool);
-    void slotResetPassword();
 
 private:
     Ui::CharmPreferences m_ui;
