@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mathias Hasselmann <mathias.hasselmann@kdab.com>
 
@@ -31,13 +31,14 @@
 
 #include "ViewHelpers.h"
 
-CommentEditorPopup::CommentEditorPopup( QWidget *parent )
-    : QDialog( parent )
-    , ui( new Ui::CommentEditorPopup )
+CommentEditorPopup::CommentEditorPopup(QWidget *parent)
+    : QDialog(parent)
+    , ui(new Ui::CommentEditorPopup)
 {
-    ui->setupUi( this );
-    ui->buttonBox->button( QDialogButtonBox::Ok )->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_Return ) );
-    ui->textEdit->setFocus( Qt::TabFocusReason );
+    ui->setupUi(this);
+    ui->buttonBox->button(QDialogButtonBox::Ok)->setShortcut(QKeySequence(Qt::CTRL
+                                                                          + Qt::Key_Return));
+    ui->textEdit->setFocus(Qt::TabFocusReason);
 }
 
 CommentEditorPopup::~CommentEditorPopup()
@@ -47,28 +48,31 @@ CommentEditorPopup::~CommentEditorPopup()
 
 void CommentEditorPopup::loadEvent(EventId id)
 {
-    Event event = DATAMODEL->eventForId( id );
+    Event event = DATAMODEL->eventForId(id);
 
-    if ( !event.isValid() ) {
+    if (!event.isValid()) {
         m_id = EventId();
         return;
     }
 
     m_id = id;
-    ui->textEdit->setPlainText( event.comment() );
+    ui->textEdit->setPlainText(event.comment());
 }
 
 void CommentEditorPopup::accept()
 {
     const QString t = ui->textEdit->toPlainText();
-    Event event = DATAMODEL->eventForId( m_id );
-    if ( event.isValid() ) {
-        event.setComment( t );
-        DATAMODEL->modifyEvent( event );
+    Event event = DATAMODEL->eventForId(m_id);
+    if (event.isValid()) {
+        event.setComment(t);
+        DATAMODEL->modifyEvent(event);
     } else { // event already gone? should never happen, but you never know
-        QPointer<QObject> that( this );
-        QMessageBox::critical( this, tr("Error"), tr("Could not save the comment, the edited event was deleted in the meantime."), QMessageBox::Ok );
-        if ( !that ) // in case the popup was deleted while the msg box was open
+        QPointer<QObject> that(this);
+        QMessageBox::critical(this, tr("Error"),
+                              tr(
+                                  "Could not save the comment, the edited event was deleted in the meantime."),
+                              QMessageBox::Ok);
+        if (!that)   // in case the popup was deleted while the msg box was open
             return;
     }
     QDialog::accept();
