@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -26,16 +26,15 @@
 
 #include <QFileDialog>
 
-ConfigurationDialog::ConfigurationDialog( const Configuration& config,
-                                          QWidget* parent )
-    : QDialog( parent )
-    , m_config( config )
+ConfigurationDialog::ConfigurationDialog(const Configuration &config, QWidget *parent)
+    : QDialog(parent)
+    , m_config(config)
 {
-    m_ui.setupUi( this );
-    m_ui.nameLineEdit->setText( config.user.name() );
-    m_ui.databaseLocation->setText( config.localStorageDatabase );
-    connect( m_ui.buttonBox, SIGNAL(rejected()), SLOT(reject()) );
-    connect( m_ui.buttonBox, SIGNAL(accepted()), SLOT(accept()) );
+    m_ui.setupUi(this);
+    m_ui.nameLineEdit->setText(config.user.name());
+    m_ui.databaseLocation->setText(config.localStorageDatabase);
+    connect(m_ui.buttonBox, &QDialogButtonBox::rejected, this, &ConfigurationDialog::reject);
+    connect(m_ui.buttonBox, &QDialogButtonBox::accepted, this, &ConfigurationDialog::accept);
 #ifdef Q_OS_ANDROID
     setWindowState(windowState() | Qt::WindowMaximized);
 #endif
@@ -46,16 +45,16 @@ Configuration ConfigurationDialog::configuration() const
     return m_config;
 }
 
-void ConfigurationDialog::on_databaseLocation_textChanged( const QString& text )
+void ConfigurationDialog::on_databaseLocation_textChanged(const QString &)
 {
     checkInput();
 }
 
 void ConfigurationDialog::accept()
 {
-    m_config.installationId = 1;
-    m_config.user.setId( 1 );
-    m_config.user.setName( m_ui.nameLineEdit->text() );
+    m_config.installationId = m_config.createInstallationId();
+    m_config.user.setId(1);
+    m_config.user.setName(m_ui.nameLineEdit->text());
     m_config.localStorageType = CHARM_SQLITE_BACKEND_DESCRIPTOR;
     m_config.localStorageDatabase = m_ui.databaseLocation->text();
     m_config.newDatabase = true;
@@ -65,22 +64,19 @@ void ConfigurationDialog::accept()
 
 void ConfigurationDialog::on_databaseLocationButton_clicked()
 {
-    QString filename = QFileDialog::getSaveFileName( this, tr( "Choose Database Location..." ) );
-    if ( ! filename.isNull() )
-    {
-        m_ui.databaseLocation->setText( filename );
-    }
+    QString filename = QFileDialog::getSaveFileName(this, tr("Choose Database Location..."));
+    if (!filename.isNull())
+        m_ui.databaseLocation->setText(filename);
 }
 
-void ConfigurationDialog::on_nameLineEdit_textChanged( const QString& text )
+void ConfigurationDialog::on_nameLineEdit_textChanged(const QString &)
 {
     checkInput();
 }
 
 void ConfigurationDialog::checkInput()
 {
-    const bool ok = ! m_ui.databaseLocation->text().isEmpty() && ! m_ui.nameLineEdit->text().isEmpty();
-    m_ui.buttonBox->button( QDialogButtonBox::Ok )->setEnabled( ok );
+    const bool ok = !m_ui.databaseLocation->text().isEmpty()
+                    && !m_ui.nameLineEdit->text().isEmpty();
+    m_ui.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(ok);
 }
-
-#include "moc_ConfigurationDialog.cpp"
