@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -33,15 +33,16 @@ class DateEntrySyncer : public QObject
 {
     Q_OBJECT
 public:
-    DateEntrySyncer( QSpinBox* weekNumberSB, QSpinBox* yearSB, QDateEdit* dateedit, int weekDay=1, QObject* parent=nullptr );
+    DateEntrySyncer(QSpinBox *weekNumberSB, QSpinBox *yearSB, QDateEdit *dateedit, int weekDay = 1,
+                    QObject *parent = nullptr);
 
 private Q_SLOTS:
     void dateSelectionChanged();
 
 private:
-    QSpinBox* m_week;
-    QSpinBox* m_year;
-    QDateEdit* m_date;
+    QSpinBox *m_week;
+    QSpinBox *m_year;
+    QDateEdit *m_date;
     int m_weekDay;
 };
 
