@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Michel Boyer de la Giroday <michel.gitroday@kdab.com>
 
@@ -21,7 +21,6 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
 #ifndef FINDANDREPLACEEVENTSDIALOG_H
 #define FINDANDREPLACEEVENTSDIALOG_H
 
@@ -44,12 +43,12 @@ class FindAndReplaceEventsDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit FindAndReplaceEventsDialog( QWidget* parent = nullptr );
+    explicit FindAndReplaceEventsDialog(QWidget *parent = nullptr);
     ~FindAndReplaceEventsDialog() override;
 
     QList<Event> modifiedEvents() const;
 
-private slots:
+private Q_SLOTS:
     void slotSelectTaskToSearch();
     void slotSelectTaskToReplaceWith();
     void slotTimeSpansChanged();
@@ -58,19 +57,19 @@ private slots:
 private:
 
     enum SelectTaskType {
-         TaskToSearch,
-         TaskToReplaceWith
+        TaskToSearch,
+        TaskToReplaceWith
     };
 
     void searchProjectCode();
-    void selectTask( SelectTaskType type );
-    void eventChangesCompleted( const Event& event );
+    void selectTask(SelectTaskType type);
+    void eventChangesCompleted(const Event &event);
 
     TaskId m_taskToSearch = {};
     TaskId m_taskToReplaceWith = {};
     TimeSpan m_timeSpan;
-    QPushButton* m_replace;
-    QPushButton* m_cancel;
+    QPushButton *m_replace;
+    QPushButton *m_cancel;
     QList<Event> m_foundEvents;
     QList<Event> m_modifiedEvents;
     QScopedPointer<EventModelFilter> m_model;
