@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -32,12 +32,12 @@ class HttpJobProgressDialog : public QProgressDialog
 {
     Q_OBJECT
 public:
-    explicit HttpJobProgressDialog( HttpJob* job, QWidget* parent = nullptr );
+    explicit HttpJobProgressDialog(HttpJob *job, QWidget *parent = nullptr);
 
 private Q_SLOTS:
-    void jobFinished( HttpJob* );
+    void jobFinished(HttpJob *);
     void jobTransferStarted();
-    void jobPasswordRequested();
+    void jobPasswordRequested(HttpJob::PasswordRequestReason reason);
 
 private:
     QPointer<HttpJob> m_job;
