@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -24,11 +24,25 @@
 #include "IdleCorrectionDialog.h"
 #include "ui_IdleCorrectionDialog.h"
 
-IdleCorrectionDialog::IdleCorrectionDialog( QWidget* parent )
-    : QDialog( parent )
-    , m_ui( new Ui::IdleCorrectionDialog )
+#include <Core/CharmConstants.h>
+
+#include <QTimer>
+
+IdleCorrectionDialog::IdleCorrectionDialog(const IdleDetector::IdlePeriod &idlePeriod,
+                                           QWidget *parent)
+    : QDialog(parent)
+    , m_ui(new Ui::IdleCorrectionDialog)
+    , m_start(idlePeriod.first)
 {
-    m_ui->setupUi( this );
+    m_ui->setupUi(this);
+
+    updateDuration();
+
+    auto timer = new QTimer(this);
+    timer->setInterval(60000);
+
+    connect(timer, &QTimer::timeout, this, &IdleCorrectionDialog::updateDuration);
+    timer->start();
 }
 
 IdleCorrectionDialog::~IdleCorrectionDialog()
@@ -37,15 +51,24 @@ IdleCorrectionDialog::~IdleCorrectionDialog()
 
 IdleCorrectionDialog::Result IdleCorrectionDialog::result() const
 {
-    if ( m_ui->ignore->isChecked() ) {
+    if (m_ui->ignore->isChecked()) {
         return Idle_Ignore;
-    } else if ( m_ui->endEvent->isChecked() ) {
+    } else if (m_ui->endEvent->isChecked()) {
         return Idle_EndEvent;
+    } else if (m_ui->restartEvent->isChecked()) {
+        return Idle_RestartEvent;
     } else {
-        Q_ASSERT( false ); // unhandled whatever?
+        Q_ASSERT(false);   // unhandled whatever?
     }
 
     return Idle_NoResult;
 }
 
-#include "moc_IdleCorrectionDialog.cpp"
+void IdleCorrectionDialog::updateDuration()
+{
+    const auto secs = m_start.secsTo(QDateTime::currentDateTime());
+    m_ui->idleLabel->setText(
+        tr(
+            "Charm detected that the computer became idle for %1 hours, while an event was in progress.")
+        .arg(hoursAndMinutes(secs)));
+}
