@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -24,11 +24,13 @@
 #ifndef IDLECORRECTIONDIALOG_H
 #define IDLECORRECTIONDIALOG_H
 
+#include "Idle/IdleDetector.h"
+
 #include <QDialog>
 #include <QScopedPointer>
 
 namespace Ui {
-    class IdleCorrectionDialog;
+class IdleCorrectionDialog;
 }
 
 class IdleCorrectionDialog : public QDialog
@@ -39,16 +41,21 @@ public:
     enum Result {
         Idle_NoResult,
         Idle_Ignore,
-        Idle_EndEvent
+        Idle_EndEvent,
+        Idle_RestartEvent
     };
 
-    explicit IdleCorrectionDialog( QWidget* parent = nullptr );
+    explicit IdleCorrectionDialog(const IdleDetector::IdlePeriod &idlePeriod,
+                                  QWidget *parent = nullptr);
     ~IdleCorrectionDialog() override;
 
     Result result() const;
 
 private:
+    void updateDuration();
+
     QScopedPointer<Ui::IdleCorrectionDialog> m_ui;
+    QDateTime m_start;
 };
 
 #endif
