@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -31,7 +31,7 @@
 #include <QTimer>
 
 namespace Ui {
-    class ReportPreviewWindow;
+class ReportPreviewWindow;
 }
 
 class QPushButton;
@@ -41,22 +41,22 @@ class ReportPreviewWindow : public QDialog
     Q_OBJECT
 
 public:
-    explicit ReportPreviewWindow( QWidget* parent = nullptr );
+    explicit ReportPreviewWindow(QWidget *parent = nullptr);
     ~ReportPreviewWindow() override;
 
-signals:
-    void anchorClicked(const QUrl& which);
+Q_SIGNALS:
+    void anchorClicked(const QUrl &which);
 
 protected:
-    void setDocument( const QTextDocument* document );
+    void setDocument(const QTextDocument *document);
     QDomDocument createReportTemplate() const;
-    QPushButton* saveToXmlButton() const;
-    QPushButton* saveToTextButton() const;
-    QPushButton* uploadButton() const;
+    QPushButton *saveToXmlButton() const;
+    QPushButton *saveToTextButton() const;
+    QPushButton *uploadButton() const;
 
     QTimer m_updateTimer;
 
-private slots:
+private Q_SLOTS:
     virtual void slotSaveToXml();
     virtual void slotSaveToText();
     virtual void slotPrint();
