@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -38,20 +38,20 @@ class TaskIdDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit TaskIdDialog( TaskModelInterface* model, TasksView* parent );
+    explicit TaskIdDialog(TaskModelInterface *model, TasksView *parent);
     ~TaskIdDialog() override;
 
-    void setSuggestedId( int );
+    void setSuggestedId(int);
     int selectedId() const;
 
     QString taskName() const;
 
-private slots:
-    void on_spinBox_valueChanged( int );
+private Q_SLOTS:
+    void on_spinBox_valueChanged(int);
 
 private:
     Ui::TaskIdDialog m_ui;
-    TaskModelInterface* m_model;
+    TaskModelInterface *m_model;
 };
 
 #endif
