@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -31,8 +31,8 @@
 
 #include "CharmCMake.h"
 
-TimeSheetReport::TimeSheetReport( QWidget* parent )
-    : ReportPreviewWindow( parent )
+TimeSheetReport::TimeSheetReport(QWidget *parent)
+    : ReportPreviewWindow(parent)
 {
 }
 
@@ -41,8 +41,7 @@ TimeSheetReport::~TimeSheetReport()
 }
 
 void TimeSheetReport::setReportProperties(
-    const QDate& start, const QDate& end,
-    TaskId rootTask, bool activeTasksOnly )
+    const QDate &start, const QDate &end, TaskId rootTask, bool activeTasksOnly)
 {
     m_start = start;
     m_end = end;
@@ -59,65 +58,63 @@ void TimeSheetReport::slotUpdate()
 void TimeSheetReport::slotSaveToXml()
 {
     // first, ask for a file name:
-    QString filename = getFileName( tr("Charm reports (*.charmreport)") );
+    QString filename = getFileName(tr("Charm reports (*.charmreport)"));
     if (filename.isEmpty())
         return;
 
-    QFileInfo fileinfo( filename );
-    if ( fileinfo.suffix().isEmpty() ) {
-        filename += QLatin1String( ".charmreport" );
-    }
+    QFileInfo fileinfo(filename);
+    if (fileinfo.suffix().isEmpty())
+        filename += QLatin1String(".charmreport");
 
-    QByteArray payload = saveToXml();
+    QByteArray payload = saveToXml(IncludeTaskList);
     if (payload.isEmpty())
         return; // Error should have been already displayed by saveToXml()
 
-    QFile file( filename );
-    if ( file.open( QIODevice::WriteOnly ) ) {
-        file.write( payload );
+    QFile file(filename);
+    if (file.open(QIODevice::WriteOnly)) {
+        file.write(payload);
     } else {
-        QMessageBox::critical( this, tr( "Error saving report" ),
-                               tr( "Cannot write to selected location:\n%1" ).arg( file.errorString() ) );
+        QMessageBox::critical(this, tr("Error saving report"),
+                              tr("Cannot write to selected location:\n%1").arg(file.errorString()));
     }
 }
 
 void TimeSheetReport::slotSaveToText()
 {
     // first, ask for a file name:
-    const QString filename = getFileName( "Text files (*.txt)" );
+    const QString filename = getFileName(QStringLiteral("Text files (*.txt)"));
     if (filename.isEmpty())
         return;
 
-    QFile file( filename );
-    if ( !file.open( QIODevice::WriteOnly ) ) {
-        QMessageBox::critical( this, tr( "Error saving report" ),
-                               tr( "Cannot write to selected location:\n%1" )
-                               .arg( file.errorString() ) );
+    QFile file(filename);
+    if (!file.open(QIODevice::WriteOnly)) {
+        QMessageBox::critical(this, tr("Error saving report"),
+                              tr("Cannot write to selected location:\n%1")
+                              .arg(file.errorString()));
         return;
     }
-    file.write( saveToText() );
+    file.write(saveToText());
     file.close();
 }
 
-QString TimeSheetReport::getFileName( const QString& filter )
+QString TimeSheetReport::getFileName(const QString &filter)
 {
     QSettings settings;
     QString path;
-    if ( settings.contains( MetaKey_ReportsRecentSavePath ) ) {
-        path = settings.value( MetaKey_ReportsRecentSavePath ).toString();
-        QDir dir( path );
-        if ( !dir.exists() ) path = QString();
+    if (settings.contains(MetaKey_ReportsRecentSavePath)) {
+        path = settings.value(MetaKey_ReportsRecentSavePath).toString();
+        QDir dir(path);
+        if (!dir.exists()) path = QString();
     }
     // suggest file name:
     path += QDir::separator() + suggestedFileName();
     // ask:
-    QString filename = QFileDialog::getSaveFileName( this, tr( "Enter File Name" ), path, filter );
-    if ( filename.isEmpty() )
+    QString filename = QFileDialog::getSaveFileName(this, tr("Enter File Name"), path, filter);
+    if (filename.isEmpty())
         return QString();
-    QFileInfo fileinfo( filename );
+    QFileInfo fileinfo(filename);
     path = fileinfo.absolutePath();
-    if ( !path.isEmpty() ) {
-        settings.setValue( MetaKey_ReportsRecentSavePath, path );
-    }
+    if (!path.isEmpty())
+        settings.setValue(MetaKey_ReportsRecentSavePath, path);
     return filename;
 }
