@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -25,23 +25,19 @@
 
 #include "ApplicationCore.h"
 
-
-TrayIcon::TrayIcon(QObject* parent)
+TrayIcon::TrayIcon(QObject *parent)
+    : QSystemTrayIcon(parent)
 {
-    connect(this,
-            SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
-            SLOT(slotActivated(QSystemTrayIcon::ActivationReason)));
+    connect(this, &QSystemTrayIcon::activated, this, &TrayIcon::slotActivated);
 }
 
 TrayIcon::~TrayIcon()
 {
-
 }
 
 void TrayIcon::slotActivated(QSystemTrayIcon::ActivationReason reason)
 {
-    switch(reason)
-    {
+    switch (reason) {
     case QSystemTrayIcon::Context:
         // show context menu
         // m_systrayContextMenu.show();
@@ -49,7 +45,7 @@ void TrayIcon::slotActivated(QSystemTrayIcon::ActivationReason reason)
     case QSystemTrayIcon::Trigger: //(single click)
     case QSystemTrayIcon::DoubleClick:
 #ifndef Q_OS_OSX
-        ApplicationCore::instance().showMainWindow( ApplicationCore::ShowMode::ShowAndRaise );
+        ApplicationCore::instance().showMainWindow(ApplicationCore::ShowMode::ShowAndRaise);
 #endif
         break;
     case QSystemTrayIcon::MiddleClick:
@@ -61,5 +57,3 @@ void TrayIcon::slotActivated(QSystemTrayIcon::ActivationReason reason)
         break;
     }
 }
-
-#include "moc_TrayIcon.cpp"
