@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -32,15 +32,16 @@
 #include "Configuration.h"
 
 // increment when SQL DB format changes:
-#define CHARM_DATABASE_VERSION_DESCRIPTOR "CharmDatabaseSchemaVersion"
+#define CHARM_DATABASE_VERSION_DESCRIPTOR QStringLiteral("CharmDatabaseSchemaVersion")
 #define CHARM_DATABASE_VERSION_BEFORE_TASK_EXPIRY 2
 #define CHARM_DATABASE_VERSION_BEFORE_TRACKABLE 3
-#define CHARM_DATABASE_VERSION 4
+#define CHARM_DATABASE_VERSION_BEFORE_COMMENT 4
+#define CHARM_DATABASE_VERSION 5
 #define REQUIRED_CHARM_DATABASE_VERSION CHARM_DATABASE_VERSION
 // FIXME this may have to go into some plugin configuration later:
 // FIXME also, we may need some verbose descriptors for configuration
-#define CHARM_SQLITE_BACKEND_DESCRIPTOR "sqlite"
-#define CHARM_MYSQL_BACKEND_DESCRIPTOR "mysql"
+#define CHARM_SQLITE_BACKEND_DESCRIPTOR QStringLiteral("sqlite")
+#define CHARM_MYSQL_BACKEND_DESCRIPTOR QStringLiteral("mysql")
 
 // Metadata and QSettings Keys:
 extern const QString MetaKey_MainWindowGeometry;
@@ -73,42 +74,46 @@ extern const QString MetaKey_Key_RequestEventComment;
 extern const QString MetaKey_Key_ToolButtonStyle;
 extern const QString MetaKey_Key_ShowStatusBar;
 extern const QString MetaKey_Key_EnableCommandInterface;
+extern const QString MetaKey_Key_NumberOfTaskSelectorEntries;
 
 extern const QString TrueString;
 extern const QString FalseString;
 
-#define CONFIGURATION ( Configuration::instance() )
+#define CONFIGURATION (Configuration::instance())
 
 // helper functions to persist meta data:
-template<class T> T strToT( const QString &str );
-template<> inline int strToT( const QString& str )
+template<class T> T strToT(const QString &str);
+template<> inline int strToT(const QString &str)
 {
     bool ok;
-    int ret = str.toInt( &ok );
-    Q_ASSERT( ok ); Q_UNUSED( ok );
+    int ret = str.toInt(&ok);
+    Q_ASSERT(ok);
+    Q_UNUSED(ok);
     return ret;
 }
-template<> inline bool strToT( const QString& str )
+
+template<> inline bool strToT(const QString &str)
 {
     return str.simplified() == TrueString;
 }
-#define INT_CONFIG_TYPE( TYPE )\
-template<> inline TYPE strToT( const QString& str )\
-{ return static_cast<TYPE>( strToT<int> ( str ) ); }
-INT_CONFIG_TYPE( Configuration::TimeTrackerFontSize )
-INT_CONFIG_TYPE( Configuration::DurationFormat )
-INT_CONFIG_TYPE( Configuration::TaskPrefilteringMode )
-INT_CONFIG_TYPE( Qt::ToolButtonStyle )
 
-const QString &stringForBool( bool val );
+#define INT_CONFIG_TYPE(TYPE) \
+    template<> inline TYPE strToT(const QString &str) \
+    { return static_cast<TYPE>(strToT<int>(str)); }
+INT_CONFIG_TYPE(Configuration::TimeTrackerFontSize)
+INT_CONFIG_TYPE(Configuration::DurationFormat)
+INT_CONFIG_TYPE(Configuration::TaskPrefilteringMode)
+INT_CONFIG_TYPE(Qt::ToolButtonStyle)
+
+const QString &stringForBool(bool val);
 
 class Controller;
 class CharmDataModel;
 
-void connectControllerAndModel( Controller*, CharmDataModel* );
+void connectControllerAndModel(Controller *, CharmDataModel *);
 
 // helpers:
 /** A string containing hh:mm for the given duration of seconds. */
-QString hoursAndMinutes( int seconds );
+QString hoursAndMinutes(int seconds);
 
 #endif
