@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -23,34 +23,42 @@
 
 #include <CharmExceptions.h>
 
-CharmException::CharmException( const QString& message )
-    : m_message( message )
-{}
+CharmException::CharmException(const QString &message)
+    : m_message(message)
+{
+}
 
-QString CharmException::what() const throw() {
+QString CharmException::what() const throw()
+{
     return m_message;
 }
 
-ParseError::ParseError( const QString& text )
-    : CharmException( text )
-{}
+ParseError::ParseError(const QString &text)
+    : CharmException(text)
+{
+}
 
-XmlSerializationException:: XmlSerializationException( const QString& message )
-    : CharmException( message )
-{}
+XmlSerializationException:: XmlSerializationException(const QString &message)
+    : CharmException(message)
+{
+}
 
-UnsupportedDatabaseVersionException::UnsupportedDatabaseVersionException( const QString& message )
-    : CharmException( message )
-{}
+UnsupportedDatabaseVersionException::UnsupportedDatabaseVersionException(const QString &message)
+    : CharmException(message)
+{
+}
 
-InvalidTaskListException::InvalidTaskListException( const QString& message )
-    : CharmException( message )
-{}
+InvalidTaskListException::InvalidTaskListException(const QString &message)
+    : CharmException(message)
+{
+}
 
-TransactionException::TransactionException( const QString& text )
-    : CharmException( text )
-{}
+TransactionException::TransactionException(const QString &text)
+    : CharmException(text)
+{
+}
 
 AlreadyRunningException::AlreadyRunningException()
-    : CharmException( QString() )
-{}
+    : CharmException(QString())
+{
+}
