@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -50,23 +50,25 @@ public:
     };
 
     enum DurationFormat {
-        Minutes=0,
+        Minutes = 0,
         Decimal
     };
 
-    bool operator== ( const Configuration& other ) const;
+    bool operator==(const Configuration &other) const;
 
-    static Configuration& instance();
+    static Configuration &instance();
 
-    void writeTo( QSettings& );
+    void writeTo(QSettings &);
     // read the configuration from the settings object
     // this will not modify the settings group etc but just use it
     // returns true if all individual settings have been found (the
     // configuration is complete)
-    bool readFrom( QSettings& );
+    bool readFrom(QSettings &);
 
     // helper method
-    void dump( const QString& why = QString::null );
+    void dump(const QString &why = QString::null);
+
+    quint32 createInstallationId() const;
 
     User user;  // this user's id
     TaskPrefilteringMode taskPrefilteringMode = TaskPrefilter_ShowAll;
@@ -78,10 +80,11 @@ public:
     bool warnUnuploadedTimesheets = true;
     bool requestEventComment = false;
     bool enableCommandInterface = false;
+    int numberOfTaskSelectorEntries = 5;
 
     // these are stored in QSettings, since we need this information to locate and open the database:
     QString configurationName;
-    int installationId = 0;
+    quint32 installationId = 0;
     QString localStorageType; // SqLite, MySql, ...
     QString localStorageDatabase; // database name (path, with sqlite)
     bool newDatabase = false; // true if the configuration has just been created
@@ -97,12 +100,11 @@ private:
     friend class SqLiteStorageTests;
     friend class ControllerTests;
     // these are all the persisted metadata settings, and the constructor is only used during test runs:
-    Configuration( TaskPrefilteringMode taskPrefilteringMode, TimeTrackerFontSize,
-                   DurationFormat durationFormat, bool detectIdling, Qt::ToolButtonStyle buttonstyle,
-                   bool showStatusBar, bool warnUnuploadedTimesheets, bool _requestEventComment,
-                   bool enableCommandInterface );
+    Configuration(TaskPrefilteringMode taskPrefilteringMode, TimeTrackerFontSize,
+                  DurationFormat durationFormat, bool detectIdling, Qt::ToolButtonStyle buttonstyle,
+                  bool showStatusBar, bool warnUnuploadedTimesheets, bool _requestEventComment,
+                  bool enableCommandInterface, int _numberOfTaskSelectorEntries);
     Configuration();
 };
 
-
 #endif
