@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -39,57 +39,56 @@ typedef int EventId;
 /** An event is a recorded time for a task.
     It records the according task, the duration and a possible
     comment. */
-class Event {
+class Event
+{
 public:
     Event();
 
-    bool operator == ( const Event& other ) const;
+    bool operator ==(const Event &other) const;
 
-    bool operator != ( const Event& other ) const
-    { return ! operator==( other ); }
+    bool operator !=(const Event &other) const
+    {
+        return !operator==(other);
+    }
 
     EventId id() const;
 
-    void setId( EventId id );
+    void setId(EventId id);
 
     int userId() const;
 
-    void setUserId( int userId );
+    void setUserId(int userId);
 
     int reportId() const;
 
-    void setReportId( int userId );
-
-    void setInstallationId( int instId );
-
-    int installationId() const;
+    void setReportId(int userId);
 
     bool isValid() const;
 
     TaskId taskId() const;
 
-    void setTaskId( TaskId id);
+    void setTaskId(TaskId id);
 
     QString comment() const;
 
-    void setComment( const QString& );
+    void setComment(const QString &);
 
-    QDateTime startDateTime( Qt::TimeSpec timeSpec = Qt::LocalTime ) const;
+    QDateTime startDateTime(Qt::TimeSpec timeSpec = Qt::LocalTime) const;
 
-    void setStartDateTime( const QDateTime& start = QDateTime::currentDateTime() );
+    void setStartDateTime(const QDateTime &start = QDateTime::currentDateTime());
 
-    QDateTime endDateTime( Qt::TimeSpec timeSpec = Qt::LocalTime ) const;
+    QDateTime endDateTime(Qt::TimeSpec timeSpec = Qt::LocalTime) const;
 
-    void setEndDateTime( const QDateTime& end = QDateTime::currentDateTime() );
+    void setEndDateTime(const QDateTime &end = QDateTime::currentDateTime());
 
     /** Returns the duration of this event in seconds. */
-    int duration () const;
+    int duration() const;
 
     void dump() const;
 
-    QDomElement toXml( QDomDocument ) const;
+    QDomElement toXml(QDomDocument) const;
 
-    static Event fromXml( const QDomElement&,  int databaseSchemaVersion = 1 );
+    static Event fromXml(const QDomElement &, int databaseSchemaVersion = 1);
     static QString tagName();
 
 private:
@@ -99,8 +98,6 @@ private:
      * if the event is imported from a report.
      */
     int m_reportid = {};
-    /** The installation-unique id of the event. */
-    int m_installationId = {};
     int m_id = {};
     /** The task this event belongs to. */
     TaskId m_taskId = {};
@@ -122,6 +119,6 @@ typedef QList<EventId> EventIdList;
 /** A map of events. */
 typedef std::map<EventId, Event> EventMap;
 
-void dumpEvents( const EventList& events );
+void dumpEvents(const EventList &events);
 
 #endif
