@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2008-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2008-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -28,11 +28,15 @@
 
 #include <QSqlDatabase>
 
-class MySqlStorage: public SqlStorage
+class MySqlStorage : public SqlStorage
 {
 public:
     struct Parameters {
-        Parameters() : port( 3309), database( "Charm" ) {}
+        Parameters() : port(3309)
+            , database(QStringLiteral("Charm"))
+        {
+        }
+
         unsigned int port;
         QString database;
         QString name;
@@ -43,17 +47,16 @@ public:
     MySqlStorage();
     virtual ~MySqlStorage();
 
-    QSqlDatabase& database() override;
+    QSqlDatabase &database() override;
 
     QString description() const override;
-    bool connect(Configuration&) override;
+    bool connect(Configuration &) override;
     bool disconnect() override;
-    int installationId() const override;
-    bool createDatabase(Configuration&) override;
+    bool createDatabase(Configuration &) override;
     bool createDatabaseTables() override;
 
     static Parameters parseParameterEnvironmentVariable();
-    void configure( const Parameters& );
+    void configure(const Parameters &);
 protected:
     QString lastInsertRowFunction() const override;
 
