@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Mike McQuaid <mike.mcquaid@kdab.com>
@@ -39,21 +39,19 @@ public:
     ~SqLiteStorage();
 
     QString description() const override;
-    bool connect( Configuration& ) override;
+    bool connect(Configuration &) override;
     bool disconnect() override;
 
-    QSqlDatabase& database() override;
-    int installationId() const override;
+    QSqlDatabase &database() override;
 
 protected:
-    bool createDatabase( Configuration& ) override;
+    bool createDatabase(Configuration &) override;
     bool createDatabaseTables() override;
-    bool migrateDatabaseDirectory(QDir, const QDir & ) const;
+    bool migrateDatabaseDirectory(QDir, const QDir &) const;
     QString lastInsertRowFunction() const override;
 
 private:
     QSqlDatabase m_database;
-    int m_installationId = 0;
 };
 
 #endif
