@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -29,37 +29,42 @@
 #include <QSqlDriver>
 #include <QSqlError>
 
-SqlRaiiTransactor::SqlRaiiTransactor( QSqlDatabase& database )
-    : m_database ( database )
+SqlRaiiTransactor::SqlRaiiTransactor(QSqlDatabase &database)
+    : m_database(database)
 {
-    if ( ! database.driver()->hasFeature( QSqlDriver::Transactions ) ) {
-        throw TransactionException( QObject::tr( "Database driver does not support transactions." ) );
-    }
+    if (!database.driver()->hasFeature(QSqlDriver::Transactions))
+        throw TransactionException(QObject::tr("Database driver does not support transactions."));
     m_active = m_database.transaction();
-    if ( ! m_active ) {
-        throw TransactionException( QObject::tr( "Starting a transaction failed: %1" ).arg( m_database.lastError().text() ) );
+    if (!m_active) {
+        throw TransactionException(QObject::tr("Starting a transaction failed: %1").arg(m_database.
+                                                                                        lastError().
+                                                                                        text()));
     }
 }
 
-SqlRaiiTransactor::~SqlRaiiTransactor() {
-    if ( m_active ) {
-        if ( ! m_database.rollback() ) {
+SqlRaiiTransactor::~SqlRaiiTransactor()
+{
+    if (m_active) {
+        if (!m_database.rollback())
             qWarning() << "Failed to rollback transaction: " << m_database.lastError().text();
-        }
     }
 }
 
-bool SqlRaiiTransactor::isActive() const {
+bool SqlRaiiTransactor::isActive() const
+{
     return m_active;
 }
 
-bool SqlRaiiTransactor::commit() {
-    if ( m_active ) {
-        if ( m_database.commit() ) {
+bool SqlRaiiTransactor::commit()
+{
+    if (m_active) {
+        if (m_database.commit()) {
             m_active = false;
             return true;
         }
-        throw TransactionException( QObject::tr( "Failed to commit transaction: " ) + m_database.lastError().text() );
+        throw TransactionException(QObject::tr(
+                                       "Failed to commit transaction: ")
+                                   + m_database.lastError().text());
     }
     return false;
 }
