@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -26,9 +26,10 @@
 
 class QSqlDatabase;
 
-class SqlRaiiTransactor {
+class SqlRaiiTransactor
+{
 public:
-    explicit SqlRaiiTransactor( QSqlDatabase& database );
+    explicit SqlRaiiTransactor(QSqlDatabase &database);
     ~SqlRaiiTransactor();
 
     bool isActive() const;
@@ -36,7 +37,7 @@ public:
     bool commit();
 private:
     bool m_active = false;
-    QSqlDatabase& m_database;
+    QSqlDatabase &m_database;
 };
 
 #endif
