@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -34,8 +34,8 @@ class BackendIntegrationTests : public TestApplication
 public:
     BackendIntegrationTests();
 
-private slots:
-    void initTestCase ();
+private Q_SLOTS:
+    void initTestCase();
 
     void initialValuesTest();
 
@@ -43,13 +43,13 @@ private slots:
 
     void biggerCreateModifyDeleteTaskTest();
 
-    void cleanupTestCase ();
+    void cleanupTestCase();
 
 private:
-    const TaskList& referenceTasks();
+    const TaskList &referenceTasks();
     // returns true if both lists contain the same tasks, even if not
     // in the same order:
-    bool contentsEqual( const TaskList& list1, const TaskList& list2 );
+    bool contentsEqual(const TaskList &list1, const TaskList &list2);
 };
 
 #endif
