@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
   Author: Olivier JG <olivier.de.gaalon@kdab.com>
@@ -31,7 +31,7 @@ class DatesTests : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void testDateByWeekNumberAndWorkDay();
     void testWeekDayInWeekOf();
     void testNumberOfWeeksInYear_data();
