@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2008-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2008-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -33,7 +33,7 @@ class ImportExportTests : public TestApplication
 public:
     ImportExportTests();
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
     void importExportTest();
     void importBenchmark();
@@ -41,7 +41,7 @@ private slots:
     void cleanupTestCase();
 
 private:
-    void importDatabase( const QString& filename );
+    void importDatabase(const QString &filename);
 };
 
 #endif
