@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -35,7 +35,7 @@ class SqlTransactionTests : public QObject
 public:
     SqlTransactionTests();
 
-private slots:
+private Q_SLOTS:
     void testMySqlDriverRequirements();
     void testSqLiteDriverRequirements();
 #if 0
@@ -48,5 +48,4 @@ private:
     MySqlStorage prepareMySqlStorage();
 };
 
-
 #endif // SQLTRANSACTIONTESTS_H
