@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -35,7 +35,7 @@ class XmlSerializationTests : public QObject
 public:
     XmlSerializationTests();
 
-private slots:
+private Q_SLOTS:
     void testEventSerialization();
     void testTaskSerialization();
     void testTaskListSerialization();
