@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2009-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2009-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -37,39 +37,38 @@ extern "C" {
 
 using namespace TimesheetGenerator;
 
-Options::Options( int argc, char** argv )
+Options::Options(int argc, char **argv)
 {
     opterr = 0;
     int ch;
     while ((ch = getopt(argc, argv, "vhf:d:")) != -1)
     {
-        if (ch == '?')
-        {
+        if (ch == '?') {
             // unparsable argument
             int option = optopt;
-            if (option == 'f')
-            {
-                throw UsageException(QObject::tr( "Option -f requires a filename argument" ) );
-            } else if ( option == 'd' ) {
-                throw UsageException(QObject::tr( "Option -d requires a date argument (e.g. 2009-01-01)" ) );
+            if (option == 'f') {
+                throw UsageException(QObject::tr("Option -f requires a filename argument"));
+            } else if (option == 'd') {
+                throw UsageException(QObject::tr(
+                                         "Option -d requires a date argument (e.g. 2009-01-01)"));
             } else {
-                int code = static_cast<int> ( option );
-                throw UsageException(QObject::tr("Unknown character %1").arg( code ) );
+                int code = static_cast<int>(option);
+                throw UsageException(QObject::tr("Unknown character %1").arg(code));
             }
         }
 
         switch (ch) {
-        case 'f': {
+        case 'f':
             mFile = QString::fromLocal8Bit(optarg);
             break;
-        }
-        case 'd': {
-            const QString text = QString::fromLocal8Bit( optarg );
-            QDate date = QDate::fromString( text, "yyyy-MM-dd" );
-            if ( date.isValid() ) {
+        case 'd':
+        {
+            const QString text = QString::fromLocal8Bit(optarg);
+            QDate date = QDate::fromString(text, QStringLiteral("yyyy-MM-dd"));
+            if (date.isValid()) {
                 mDate = date;
             } else {
-                throw UsageException(QObject::tr("Cannot parse date \"%1\"").arg( text ) );
+                throw UsageException(QObject::tr("Cannot parse date \"%1\"").arg(text));
             }
             break;
         }
@@ -77,25 +76,22 @@ Options::Options( int argc, char** argv )
             throw UsageException();
         case 'v':
             std::cout << CHARM_VERSION << std::endl;
-            exit( 0 );
+            exit(0);
             break;
         default:
             break;
         }
     }
 
-    if ( mFile.isEmpty() ) {
-        throw UsageException(QObject::tr( "No filename specified (-f), aborting." ) );
-    }
-    if ( ! mDate.isValid() ) {
-        throw UsageException( QObject::tr( "No date specified (-d), aborting." ) );
-    }
+    if (mFile.isEmpty())
+        throw UsageException(QObject::tr("No filename specified (-f), aborting."));
+    if (!mDate.isValid())
+        throw UsageException(QObject::tr("No date specified (-d), aborting."));
 
     using namespace std;
-    QFile file( mFile );
-    if ( ! file.exists() ) {
-        throw UsageException(QObject::tr( "Specified file not found, aborting." ) );
-    }
+    QFile file(mFile);
+    if (!file.exists())
+        throw UsageException(QObject::tr("Specified file not found, aborting."));
 }
 
 QString Options::file() const
