@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2008-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2008-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -30,8 +30,8 @@
 class TimesheetProcessorException : public std::exception
 {
 public:
-    explicit TimesheetProcessorException(const QString& text = QString::null) :
-        mWhat(text)
+    explicit TimesheetProcessorException(const QString &text = QString::null)
+        : mWhat(text)
     {
     }
 
@@ -39,7 +39,7 @@ public:
     {
     }
 
-    const char* what() const throw()
+    const char *what() const throw()
     {
         return qPrintable(mWhat);
     }
@@ -51,8 +51,8 @@ private:
 class UsageException : public TimesheetProcessorException
 {
 public:
-    explicit UsageException(const QString& text = QString::null) :
-        TimesheetProcessorException(text)
+    explicit UsageException(const QString &text = QString::null)
+        : TimesheetProcessorException(text)
     {
     }
 };
